@@ -24,12 +24,12 @@ if (require("rstanarm") &&
 
     bfr <- bayesfactor_restricted(posterior, hypothesis = hyps, prior = prior)
 
-    testthat::expect_equal(bfr$Prior_prob, c(0.2, 0.5), tolerance = 0.1)
-    testthat::expect_equal(bfr$Posterior_prob, c(0.31, 1), tolerance = 0.1)
-    testthat::expect_equal(log(bfr$BF), c(0.43, 0.69), tolerance = 0.1)
-    testthat::expect_equal(bfr$BF, bfr$Posterior_prob / bfr$Prior_prob, tolerance = 0.1)
+    expect_equal(bfr$Prior_prob, c(0.2, 0.5), tolerance = 0.1)
+    expect_equal(bfr$Posterior_prob, c(0.31, 1), tolerance = 0.1)
+    expect_equal(log(bfr$BF), c(0.43, 0.69), tolerance = 0.1)
+    expect_equal(bfr$BF, bfr$Posterior_prob / bfr$Prior_prob, tolerance = 0.1)
 
-    testthat::expect_error(bayesfactor_restricted(posterior, prior, hypothesis = "Y < 0"))
+    expect_error(bayesfactor_restricted(posterior, prior, hypothesis = "Y < 0"))
   })
 
 
@@ -37,9 +37,8 @@ if (require("rstanarm") &&
 
 
   test_that("bayesfactor_restricted RSTANARM", {
-    testthat::skip_on_cran()
-    library(rstanarm)
-    fit_stan <- stan_glm(mpg ~ wt + cyl + am, data = mtcars, refresh = 0)
+    skip_on_cran()
+    fit_stan <- stan_glm(mpg ~ wt + cyl + am, data = mtcars, refresh = 0, iter=200)
 
     hyps <- c(
       "am > 0 & cyl < 0",
@@ -54,6 +53,6 @@ if (require("rstanarm") &&
     set.seed(444)
     bfr2 <- bayesfactor_restricted(fit_stan, hypothesis = hyps)
 
-    testthat::expect_equal(bfr1, bfr2)
+    expect_equal(bfr1, bfr2)
   })
 }
